@@ -17,16 +17,16 @@ tLIT = ('wspaces', 'newlines', 'literals')
 
 >>> parser = ExampleParser(0, 'utf8', None); parser.language = 'python'
 
->>> cap_regexs = parser.capture_tag_regexs()
+>>> tag_regexs = parser.tag_regexs()
 >>> inp_regexs = parser.input_regexs()
 
 >>> ellipsis_marker = parser.ellipsis_marker()
 
 >>> input_prefix_len_range = (6, 12)
 
->>> sm = SM(cap_regexs, inp_regexs, ellipsis_marker, input_prefix_len_range)
->>> sm_norm_ws = SM_NormWS(cap_regexs, inp_regexs, ellipsis_marker, input_prefix_len_range)
->>> sm_lit = SM_NotNormWS(cap_regexs, inp_regexs, ellipsis_marker, input_prefix_len_range)
+>>> sm = SM(tag_regexs, inp_regexs, ellipsis_marker, input_prefix_len_range)
+>>> sm_norm_ws = SM_NormWS(tag_regexs, inp_regexs, ellipsis_marker, input_prefix_len_range)
+>>> sm_lit = SM_NotNormWS(tag_regexs, inp_regexs, ellipsis_marker, input_prefix_len_range)
 
 >>> def match(regexs, string):
 ...     r = re.compile(''.join(regexs), re.MULTILINE | re.DOTALL)
@@ -36,11 +36,10 @@ tLIT = ('wspaces', 'newlines', 'literals')
 
 class SM(object):
     def __init__(
-        self, capture_tag_regexs, input_regexs, ellipsis_marker,
-        input_prefix_len_range
+        self, tag_regexs, input_regexs, ellipsis_marker, input_prefix_len_range
     ):
-        self.capture_tag_regex = capture_tag_regexs.for_capture
-        self.capture_tag_split_regex = capture_tag_regexs.for_split
+        self.tag_regex = tag_regexs.for_capture
+        self.tag_split_regex = tag_regexs.for_split
         self.ellipsis_marker = ellipsis_marker
 
         self.input_capture_regex = input_regexs.for_capture
@@ -114,7 +113,7 @@ class SM(object):
         return self.emit(charno, rx, rc)
 
     def name_of_tag_or_None(self, tag):
-        name = self.capture_tag_regex.match(tag).group('name')
+        name = self.tag_regex.match(tag).group('name')
         if name == self.ellipsis_marker:
             name = None
 
@@ -177,7 +176,7 @@ class SM(object):
             '+paste' or their were not captured in a previous
             example. Or perhaps you do not want capture/paste
             anything: you want to treat the tags as literals
-            and you forgot '-tags'.
+            and you forgot '-tags' or '-capture'.
 
             The regexs are non-greedy by default with one exception: if
             the tag is unamed and it its at the end of a line
@@ -200,7 +199,7 @@ class SM(object):
                   "'+paste' or their were not captured in a previous\n"+\
                   "example. Or perhaps you do not want capture/paste\n"+\
                   "anything: you want to treat the tags as literals\n"+\
-                  "and you forgot '-tags'."
+                  "and you forgot '-tags' or '-capture'."
 
             raise ValueError(msg % (name, charno))
 
@@ -372,7 +371,7 @@ class SM(object):
 
         nl_splitter = self.one_or_more_nl_capture_regex()
         ws_splitter = self.one_or_more_ws_capture_regex()
-        tag_splitter = self.capture_tag_split_regex
+        tag_splitter = self.tag_split_regex
         input_capture_regex = self.input_capture_regex
         input_check_regex = self.input_check_regex
 
@@ -660,11 +659,10 @@ class SM(object):
 
 class SM_NormWS(SM):
     def __init__(
-        self, capture_tag_regexs, input_regexs, ellipsis_marker,
-        input_prefix_len_range
+        self, tag_regexs, input_regexs, ellipsis_marker, input_prefix_len_range
     ):
         SM.__init__(
-            self, capture_tag_regexs, input_regexs, ellipsis_marker,
+            self, tag_regexs, input_regexs, ellipsis_marker,
             input_prefix_len_range
         )
 
@@ -1011,11 +1009,10 @@ class SM_NormWS(SM):
 
 class SM_NotNormWS(SM):
     def __init__(
-        self, capture_tag_regexs, input_regexs, ellipsis_marker,
-        input_prefix_len_range
+        self, tag_regexs, input_regexs, ellipsis_marker, input_prefix_len_range
     ):
         SM.__init__(
-            self, capture_tag_regexs, input_regexs, ellipsis_marker,
+            self, tag_regexs, input_regexs, ellipsis_marker,
             input_prefix_len_range
         )
 
@@ -1087,7 +1084,7 @@ class SM_NotNormWS(SM):
             drop(last=True)  # don't care what we read next
             drop(last=True)  # don't care the second tag
             charno, _ = self.pull()
-            msg = "Two consecutive capture tags were found at %ith character. " +\
+            msg = "Two consecutive tags were found at %ith character. " +\
                   "This is ambiguous."
             raise ValueError(msg % charno)
         elif self.state in (EXHAUSTED, ERROR):
